@@ -1,35 +1,35 @@
 /*
 
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "translatorwidget.h"
-#include "translatorutil.h"
 #include "googletranslator.h"
-#include <PimCommon/NetworkManager>
+#include "translatorutil.h"
 #include <KBusyIndicatorWidget>
+#include <PimCommon/NetworkManager>
 
-#include <QPushButton>
-#include <KLocalizedString>
 #include <KConfigGroup>
-#include <KSeparator>
+#include <KLocalizedString>
 #include <KMessageBox>
+#include <KSeparator>
+#include <QPushButton>
 
-#include <QMimeData>
-#include <QIcon>
+#include <KSharedConfig>
 #include <QComboBox>
 #include <QHBoxLayout>
-#include <QVBoxLayout>
-#include <QLabel>
-#include <QToolButton>
+#include <QIcon>
 #include <QKeyEvent>
-#include <QShortcut>
-#include <QPainter>
-#include <QSplitter>
-#include <KSharedConfig>
+#include <QLabel>
+#include <QMimeData>
 #include <QNetworkConfigurationManager>
+#include <QPainter>
+#include <QShortcut>
+#include <QSplitter>
+#include <QToolButton>
+#include <QVBoxLayout>
 
 using namespace PimCommon;
 
@@ -48,7 +48,7 @@ public:
     void initLanguage();
     void fillToCombobox(const QString &lang);
 
-    QMap<QString, QMap<QString, QString> > listLanguage;
+    QMap<QString, QMap<QString, QString>> listLanguage;
     QByteArray data;
     TranslatorTextEdit *inputText = nullptr;
     KPIMTextEdit::PlainTextEditorWidget *translatedText = nullptr;
@@ -201,10 +201,10 @@ void TranslatorWidget::init()
     connect(d->abstractTranslator, &PimCommon::GoogleTranslator::translateDone, this, &TranslatorWidget::slotTranslateDone);
     connect(d->abstractTranslator, &PimCommon::GoogleTranslator::translateFailed, this, &TranslatorWidget::slotTranslateFailed);
 
-    auto *layout = new QVBoxLayout(this);
+    auto layout = new QVBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
-    auto *hboxLayout = new QHBoxLayout;
-    auto *closeBtn = new QToolButton(this);
+    auto hboxLayout = new QHBoxLayout;
+    auto closeBtn = new QToolButton(this);
     closeBtn->setObjectName(QStringLiteral("close-button"));
     closeBtn->setIcon(QIcon::fromTheme(QStringLiteral("dialog-close")));
     closeBtn->setIconSize(QSize(16, 16));
@@ -217,7 +217,7 @@ void TranslatorWidget::init()
     hboxLayout->addWidget(closeBtn);
     connect(closeBtn, &QToolButton::clicked, this, &TranslatorWidget::slotCloseWidget);
 
-    QLabel *label = new QLabel(i18nc("Translate from language", "From:"));
+    auto label = new QLabel(i18nc("Translate from language", "From:"));
     hboxLayout->addWidget(label);
     d->from = new QComboBox;
     d->from->setMinimumWidth(50);
@@ -232,12 +232,11 @@ void TranslatorWidget::init()
 
     hboxLayout->addWidget(d->to);
 
-    KSeparator *separator = new KSeparator;
+    auto separator = new KSeparator;
     separator->setOrientation(Qt::Vertical);
     hboxLayout->addWidget(separator);
 
-    d->invert = new QPushButton(
-        i18nc("Invert language choices so that from becomes to and to becomes from", "Invert"), this);
+    d->invert = new QPushButton(i18nc("Invert language choices so that from becomes to and to becomes from", "Invert"), this);
     d->invert->setObjectName(QStringLiteral("invert-button"));
     connect(d->invert, &QPushButton::clicked, this, &TranslatorWidget::slotInvertLanguage);
     hboxLayout->addWidget(d->invert);
@@ -260,7 +259,7 @@ void TranslatorWidget::init()
     connect(d->translate, &QPushButton::clicked, this, &TranslatorWidget::slotTranslate);
 
     if (!qEnvironmentVariableIsEmpty("KDEPIM_DEBUGGING")) {
-        QPushButton *debugButton = new QPushButton(i18n("Debug"));
+        auto debugButton = new QPushButton(i18n("Debug"));
         hboxLayout->addWidget(debugButton);
         connect(debugButton, &QPushButton::clicked, this, &TranslatorWidget::slotDebug);
     }
@@ -275,7 +274,7 @@ void TranslatorWidget::init()
     d->splitter = new QSplitter;
     d->splitter->setChildrenCollapsible(false);
     d->inputText = new TranslatorTextEdit(this);
-    auto *editorWidget = new KPIMTextEdit::PlainTextEditorWidget(d->inputText);
+    auto editorWidget = new KPIMTextEdit::PlainTextEditorWidget(d->inputText);
     d->inputText->setObjectName(QStringLiteral("inputtext"));
     d->inputText->setPlaceholderText(i18n("Drag text that you want to translate. (Be careful text will be send to Google Server)."));
     connect(d->inputText, &TranslatorTextEdit::textChanged, this, &TranslatorWidget::slotTextChanged);
@@ -291,7 +290,7 @@ void TranslatorWidget::init()
     layout->addWidget(d->splitter);
 
     d->initLanguage();
-    d->from->setCurrentIndex(0);   //Fill "to" combobox
+    d->from->setCurrentIndex(0); // Fill "to" combobox
     slotFromLanguageChanged(0, true);
     slotTextChanged();
     readConfig();
@@ -432,7 +431,7 @@ bool TranslatorWidget::event(QEvent *e)
     // window-global actions (e.g. Emil Sedgh binds Esc to "close tab").
     // With a shortcut override we can catch this before it gets to kactions.
     if (e->type() == QEvent::ShortcutOverride || e->type() == QEvent::KeyPress) {
-        auto *kev = static_cast<QKeyEvent * >(e);
+        auto kev = static_cast<QKeyEvent *>(e);
         if (kev->key() == Qt::Key_Escape) {
             e->accept();
             slotCloseWidget();
