@@ -4,11 +4,11 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef ADDRESSEELINEEDITLDAP_H
-#define ADDRESSEELINEEDITLDAP_H
+#pragma once
 
 #include <QMap>
-#include <QTimer>
+#include <QObject>
+class QTimer;
 
 namespace KLDAP
 {
@@ -60,4 +60,3 @@ private:
 };
 }
 
-#endif // ADDRESSEELINEEDITLDAP_H
